@@ -23,7 +23,10 @@ DEFAULT_KINDS = [
     {"vars": "**/{host_vars,group_vars,vars,defaults}/**/*.{yaml,yml}"},
     {"meta": "**/meta/main.{yaml,yml}"},
     {"yaml": ".config/molecule/config.{yaml,yml}"},  # molecule global config
-    {"yaml": "**/molecule/*/molecule.{yaml,yml}"},  # molecule config
+    {
+        "requirements": "**/molecule/*/collections.{yaml,yml}"
+    },  # molecule old collection requirements (v1), ansible 2.8 only
+    {"yaml": "**/molecule/*/{base,molecule}.{yaml,yml}"},  # molecule config
     {"playbook": "**/molecule/*/*.{yaml,yml}"},  # molecule playbooks
     {"yaml": "**/*.{yaml,yml}"},
     {"yaml": "**/.*.{yaml,yml}"},
@@ -51,6 +54,7 @@ options = Namespace(
     loop_var_prefix=None,
     offline=False,
     extra_vars=None,
+    skip_action_validation=True,
 )
 
 # Used to store detected tag deprecations
