@@ -60,6 +60,7 @@ from ansiblelint._internal.rules import (
     LoadingFailureRule,
     RuntimeErrorRule,
 )
+from ansiblelint.config import options
 from ansiblelint.constants import FileType
 from ansiblelint.errors import MatchError
 from ansiblelint.file_utils import Lintable, get_yaml_files
@@ -516,7 +517,9 @@ def normalize_task_v2(task: Dict[str, Any]) -> Dict[str, Any]:
     sanitized_task = _sanitize_task(task)
     mod_arg_parser = ModuleArgsParser(sanitized_task)
     try:
-        action, arguments, result['delegate_to'] = mod_arg_parser.parse()
+        action, arguments, result['delegate_to'] = mod_arg_parser.parse(
+            skip_action_validation=options.skip_action_validation
+        )
     except AnsibleParserError as e:
         raise MatchError(
             rule=AnsibleParserErrorRule(),
@@ -855,16 +858,16 @@ def convert_to_boolean(value: Any) -> bool:
 
 
 def nested_items(
-    data: Union[Dict[Any, Any], List[Any]]
-) -> Generator[Tuple[Any, Any], None, None]:
+    data: Union[Dict[Any, Any], List[Any]], parent: str = ""
+) -> Generator[Tuple[Any, Any, str], None, None]:
     """Iterate a nested data structure."""
     if isinstance(data, dict):
         for k, v in data.items():
-            yield k, v
-            for k, v in nested_items(v):
-                yield k, v
+            yield k, v, parent
+            for k, v, p in nested_items(v, k):
+                yield k, v, p
     if isinstance(data, list):
         for item in data:
-            yield "list-item", item
-            for k, v in nested_items(item):
-                yield k, v
+            yield "list-item", item, parent
+            for k, v, p in nested_items(item):
+                yield k, v, p
